pub(crate) fn matches_to_edit<'db>(
db: &'db dyn ExpandDatabase,
matches: &SsrMatches,
file_src: &str,
rules: &[ResolvedRule<'db>],
) -> TextEditExpand description
Returns a text edit that will replace each match in matches with its corresponding replacement
template. Placeholders in the template will have been substituted with whatever they matched to
in the original code.